@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,7 +24,10 @@
 #include <QStringList>
 #include <QXmlStreamReader>
 #include <KSieveUi/AbstractRegexpEditorLineEdit>
+#include "ksieveui_private_export.h"
 namespace KSieveUi {
+class AbstractMoveImapFolderWidget;
+class AbstractSelectEmailLineEdit;
 namespace AutoCreateScriptUtil {
 QString createMultiLine(const QString &str);
 QString createList(const QString &str, QChar separator, bool addEndSemiColon = true);
@@ -38,7 +41,7 @@ QString strValue(QXmlStreamReader &element);
 QStringList listValue(QXmlStreamReader &element);
 QString listValueToStr(QXmlStreamReader &element);
 QString fixListValue(QString valueStr);
-QString quoteStr(QString str, bool protectSlash = true);
+QString quoteStr(const QString &str, bool protectSlash = true);
 void comboboxItemNotFound(const QString &searchItem, const QString &name, QString &error);
 QString createFullWhatsThis(const QString &help, const QString &href);
 QString protectSlash(QString str);
@@ -46,6 +49,8 @@ QString indentation();
 AbstractRegexpEditorLineEdit *createRegexpEditorLineEdit(QWidget *parent = nullptr);
 QString generateConditionComment(const QString &comment);
 QString loadConditionComment(QString originalComment, const QString &comment);
+KSIEVEUI_TESTS_EXPORT KSieveUi::AbstractMoveImapFolderWidget *createImapFolderWidget();
+KSIEVEUI_TESTS_EXPORT KSieveUi::AbstractSelectEmailLineEdit *createSelectEmailsWidget();
 }
 }
 #endif // AUTOCREATESCRIPTUTIL_H
