@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,7 +30,7 @@ class SieveAction : public QObject
     Q_OBJECT
 public:
     SieveAction(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, const QString &name, const QString &label, QObject *parent = nullptr);
-    virtual ~SieveAction();
+    ~SieveAction() override;
 
     QString name() const;
     QString label() const;
@@ -69,6 +69,7 @@ Q_SIGNALS:
     void valueChanged();
 
 private:
+    Q_DISABLE_COPY(SieveAction)
     QString mName;
     QString mLabel;
     QString mComment;
