@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,17 +20,18 @@
 #define ADDRESSLINEEDIT_H
 
 #include <QLineEdit>
-
+#include <KSieveUi/AbstractSelectEmailLineEdit>
+#include "ksieveui_private_export.h"
 namespace KSieveUi {
-class AddressLineEdit : public QLineEdit
+class KSIEVEUI_TESTS_EXPORT AddressLineEdit : public AbstractSelectEmailLineEdit
 {
     Q_OBJECT
 public:
     explicit AddressLineEdit(QWidget *parent = nullptr);
-    ~AddressLineEdit();
+    ~AddressLineEdit() override;
 
-Q_SIGNALS:
-    void valueChanged();
+    void setText(const QString &str) override;
+    QString text() const override;
 
 protected:
     void focusOutEvent(QFocusEvent *ev) override;
@@ -38,8 +39,8 @@ protected:
 private:
     void slotTextChanged();
     void verifyAddress();
+    QLineEdit *mLineEdit = nullptr;
     QString mNegativeBackground;
-    bool mIncorrectEmail;
 };
 }
 
