@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,19 +28,14 @@
 #include <QWidget>
 #include <QHBoxLayout>
 #include "libksieve_debug.h"
-#include <QDomNode>
+#include <QXmlStreamReader>
 #include <QLabel>
 
 using namespace KSieveUi;
-SieveConditionHasFlag::SieveConditionHasFlag(QObject *parent)
-    : SieveCondition(QStringLiteral("hasflag"), i18n("Has Flag"), parent)
+SieveConditionHasFlag::SieveConditionHasFlag(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("hasflag"), i18n("Has Flag"), parent)
 {
-    hasVariableSupport = SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QStringLiteral("variables"));
-}
-
-SieveCondition *SieveConditionHasFlag::newAction()
-{
-    return new SieveConditionHasFlag;
+    hasVariableSupport = sieveCapabilities().contains(QLatin1String("variables"));
 }
 
 QWidget *SieveConditionHasFlag::createParamWidget(QWidget *parent) const
@@ -49,7 +44,7 @@ QWidget *SieveConditionHasFlag::createParamWidget(QWidget *parent) const
     QHBoxLayout *lay = new QHBoxLayout;
     lay->setMargin(0);
     w->setLayout(lay);
-    SelectMatchTypeComboBox *selecttype = new SelectMatchTypeComboBox;
+    SelectMatchTypeComboBox *selecttype = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     selecttype->setObjectName(QStringLiteral("matchtype"));
     connect(selecttype, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionHasFlag::valueChanged);
     lay->addWidget(selecttype);
@@ -72,8 +67,9 @@ QWidget *SieveConditionHasFlag::createParamWidget(QWidget *parent) const
     QLabel *lab = new QLabel(i18n("Value:"));
     grid->addWidget(lab, row, 0);
 
-    QLineEdit *value = new QLineEdit;
-    connect(value, &QLineEdit::textChanged, this, &SieveConditionHasFlag::valueChanged);
+    AbstractRegexpEditorLineEdit *value = AutoCreateScriptUtil::createRegexpEditorLineEdit();
+    connect(value, &AbstractRegexpEditorLineEdit::textChanged, this, &SieveConditionHasFlag::valueChanged);
+    connect(selecttype, &SelectMatchTypeComboBox::switchToRegexp, value, &AbstractRegexpEditorLineEdit::switchToRegexpEditorLineEdit);
     value->setObjectName(QStringLiteral("value"));
     grid->addWidget(value, row, 1);
 
@@ -95,17 +91,17 @@ QString SieveConditionHasFlag::code(QWidget *w) const
             result += QLatin1String(" \"") + variableNameStr + QLatin1Char('"');
         }
 
-        const QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("value"));
-        const QString valueStr = value->text();
+        const AbstractRegexpEditorLineEdit *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+        const QString valueStr = value->code();
         result += QLatin1String(" \"") + valueStr + QLatin1Char('"');
     }
-    return result;
+    return result + AutoCreateScriptUtil::generateConditionComment(comment());
 }
 
-QStringList SieveConditionHasFlag::needRequires(QWidget *) const
+QStringList SieveConditionHasFlag::needRequires(QWidget *w) const
 {
     QStringList lst;
-    if (SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QStringLiteral("imap4flags"))) {
+    if (sieveCapabilities().contains(QLatin1String("imap4flags"))) {
         lst << QStringLiteral("imap4flags");
     } else {
         lst << QStringLiteral("imapflags");
@@ -113,6 +109,8 @@ QStringList SieveConditionHasFlag::needRequires(QWidget *) const
     if (hasVariableSupport) {
         lst << QStringLiteral("variables");
     }
+    const SelectMatchTypeComboBox *matchTypeCombo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+    lst << matchTypeCombo->needRequires();
     return lst;
 }
 
@@ -123,11 +121,16 @@ bool SieveConditionHasFlag::needCheckIfServerHasCapability() const
 
 QString SieveConditionHasFlag::serverNeedsCapability() const
 {
-    if (SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QStringLiteral("imap4flags"))) {
+    return QStringLiteral("variables");
+#if 0
+    if (sieveCapabilities().contains(QLatin1String("variables"))) {
+    }
+    if (sieveCapabilities().contains(QLatin1String("imap4flags"))) {
         return QStringLiteral("imap4flags");
     } else {
         return QStringLiteral("imapflags");
     }
+#endif
 }
 
 QString SieveConditionHasFlag::help() const
@@ -135,51 +138,53 @@ QString SieveConditionHasFlag::help() const
     return i18n("The hasflag test evaluates to true if any of the variables matches any flag name.");
 }
 
-bool SieveConditionHasFlag::setParamWidgetValue(const QDomElement &element, QWidget *w, bool notCondition, QString &error)
+bool SieveConditionHasFlag::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
 {
     QStringList strList;
-    QDomNode node = element.firstChild();
-    while (!node.isNull()) {
-        QDomElement e = node.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            if (tagName == QLatin1String("tag")) {
-                SelectMatchTypeComboBox *matchTypeCombo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
-                matchTypeCombo->setCode(AutoCreateScriptUtil::tagValueWithCondition(e.text(), notCondition), name(), error);
-            } else if (tagName == QLatin1String("str")) {
-                strList << e.text();
-            } else if (tagName == QLatin1String("crlf")) {
-                //nothing
-            } else if (tagName == QLatin1String("comment")) {
-                //implement in the future ?
-            } else {
-                unknownTag(tagName, error);
-                qCDebug(LIBKSIEVE_LOG) << " SieveConditionExists::setParamWidgetValue unknown tagName " << tagName;
-            }
+    QString commentStr;
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("tag")) {
+            SelectMatchTypeComboBox *matchTypeCombo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+            matchTypeCombo->setCode(AutoCreateScriptUtil::tagValueWithCondition(element.readElementText(), notCondition), name(), error);
+        } else if (tagName == QLatin1String("str")) {
+            strList << element.readElementText();
+        } else if (tagName == QLatin1String("crlf")) {
+            element.skipCurrentElement();
+            //nothing
+        } else if (tagName == QLatin1String("comment")) {
+            commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
+        } else {
+            unknownTag(tagName, error);
+            qCDebug(LIBKSIEVE_LOG) << " SieveConditionExists::setParamWidgetValue unknown tagName " << tagName;
         }
-        node = node.nextSibling();
     }
+    if (!commentStr.isEmpty()) {
+        setComment(commentStr);
+    }
+
     switch (strList.count()) {
-    case 1: {
-        QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("value"));
-        value->setText(strList.at(0));
+    case 1:
+    {
+        AbstractRegexpEditorLineEdit *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+        value->setCode(strList.at(0));
         break;
     }
-    case 2: {
+    case 2:
         if (hasVariableSupport) {
             QLineEdit *variableName = w->findChild<QLineEdit *>(QStringLiteral("variablename"));
             variableName->setText(strList.at(0));
-            QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("value"));
-            value->setText(strList.at(1));
+            AbstractRegexpEditorLineEdit *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+            value->setCode(strList.at(1));
         } else {
             qCDebug(LIBKSIEVE_LOG) << " SieveConditionHasFlag has not variable support";
         }
         break;
-    }
     default:
         qCDebug(LIBKSIEVE_LOG) << " SieveConditionHasFlag::setParamWidgetValue str list count not correct :" << strList.count();
         break;
     }
+
     return true;
 }
 
@@ -187,4 +192,3 @@ QUrl SieveConditionHasFlag::href() const
 {
     return SieveEditorUtil::helpUrl(SieveEditorUtil::strToVariableName(name()));
 }
-
