@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -40,7 +40,7 @@ Q_SIGNALS:
 
 private:
     void initialize();
-    bool mHasSubaddressCapability;
+    bool mHasSubaddressCapability = false;
 };
 }
 
