@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -37,14 +37,11 @@ public:
 
 Q_SIGNALS:
     void valueChanged();
-
-private Q_SLOTS:
-    void slotBodyTypeChanged(int);
-
 private:
+    void slotBodyTypeChanged(int);
     void initialize();
-    KComboBox *mBodyCombobox;
-    QLineEdit *mBodyLineEdit;
+    KComboBox *mBodyCombobox = nullptr;
+    QLineEdit *mBodyLineEdit = nullptr;
 };
 }
 
