@@ -46,8 +46,10 @@ SieveDebugDialog::SieveDebugDialog(SieveImapPasswordProvider *passwordProvider,
 
     mEdit = new KPIMTextEdit::PlainTextEditorWidget(this);
     mEdit->setReadOnly(true);
-    KSyntaxHighlighting::Definition def;
-    def = mRepo.definitionForName(QStringLiteral("Sieve"));
+    const KSyntaxHighlighting::Definition def = mRepo.definitionForName(QStringLiteral("Sieve"));
+    if (!def.isValid()) {
+        qCWarning(LIBKSIEVE_LOG) << "Invalid definition name";
+    }
 
     KSyntaxHighlighting::SyntaxHighlighter *hl = new KSyntaxHighlighting::SyntaxHighlighter(mEdit->editor()->document());
     hl->setTheme((palette().color(QPalette::Base).lightness() < 128)
@@ -182,7 +184,7 @@ void SieveDebugDialog::slotGetScript(KManageSieve::SieveJob *job, bool success,
         mEdit->editor()->appendPlainText(i18n("Retrieving the script failed.\n"
                                               "The server responded:\n%1", job->errorString()));
     } else if (script.isEmpty()) {
-        mEdit->editor()->appendPlainText(i18n("(This script is empty.)\n\n"));
+        mEdit->editor()->appendPlainText(i18n("(This script is empty)\n\n"));
     } else {
         mEdit->editor()->appendPlainText(i18n(
                                              "------------------------------------------------------------\n"
@@ -226,7 +228,7 @@ void SieveDebugDialog::slotGetScriptList(KManageSieve::SieveJob *job, bool succe
             mEdit->editor()->appendPlainText(QLatin1String("* ") + *it + QLatin1Char('\n'));
         }
         mEdit->editor()->appendPlainText(QStringLiteral("\n"));
-        mEdit->editor()->appendPlainText(i18n("Active script: %1\n\n", activeScript));
+        mEdit->editor()->appendPlainText(i18n("Active script: '%1'\n\n", activeScript));
     }
 
     // Handle next job: dump scripts for this server
