@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,11 +26,12 @@ class SieveScriptDebuggerDialogTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit SieveScriptDebuggerDialogTest(QObject *parent = Q_NULLPTR);
+    explicit SieveScriptDebuggerDialogTest(QObject *parent = nullptr);
     ~SieveScriptDebuggerDialogTest();
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
+    void shouldChangeDebugButtonEnabledState();
 };
 
 #endif // SIEVESCRIPTDEBUGGERDIALOGTEST_H
