@@ -27,12 +27,13 @@
 
 using namespace KSieveUi;
 
-Vacation::Vacation(QObject *parent, bool checkOnly, const QUrl &url)
-    : QObject(parent),
-      mSieveJob(nullptr),
-      mDialog(nullptr),
-      mWasActive(false),
-      mCheckOnly(checkOnly)
+Vacation::Vacation(SieveImapPasswordProvider *passwordProvider, QObject *parent, bool checkOnly, const QUrl &url)
+    : QObject(parent)
+    , mPasswordProvider(passwordProvider)
+    , mSieveJob(nullptr)
+    , mDialog(nullptr)
+    , mWasActive(false)
+    , mCheckOnly(checkOnly)
 {
     if (url.isEmpty()) {
         mUrl = findURL(mServerName);
@@ -76,8 +77,8 @@ QUrl Vacation::findURL(QString &serverName) const
             continue;
         }
 
-        const KSieveUi::Util::AccountInfo info = KSieveUi::Util::fullAccountInfo(instance.identifier());
-        const QUrl url  = info.sieveUrl;
+        const KSieveUi::Util::AccountInfo info = KSieveUi::Util::fullAccountInfo(instance.identifier(), mPasswordProvider);
+        const QUrl url = info.sieveUrl;
         if (!url.isEmpty()) {
             serverName = instance.name();
             return url;
@@ -87,8 +88,7 @@ QUrl Vacation::findURL(QString &serverName) const
     return QUrl();
 }
 
-void Vacation::slotGetResult(KManageSieve::SieveJob *job, bool success,
-                             const QString &script, bool active)
+void Vacation::slotGetResult(KManageSieve::SieveJob *job, bool success, const QString &script, bool active)
 {
     qCDebug(LIBKSIEVE_LOG) << success
                            << ", ?," << active << ")" << endl
@@ -96,8 +96,8 @@ void Vacation::slotGetResult(KManageSieve::SieveJob *job, bool success,
                            << script;
     mSieveJob = nullptr; // job deletes itself after returning from this slot!
 
-    if (!mCheckOnly && mUrl.scheme() == QLatin1String("sieve") &&
-            !job->sieveCapabilities().contains(QStringLiteral("vacation"))) {
+    if (!mCheckOnly && mUrl.scheme() == QLatin1String("sieve")
+        && !job->sieveCapabilities().contains(QLatin1String("vacation"))) {
         KMessageBox::sorry(nullptr, i18n("Your server did not list \"vacation\" in "
                                          "its list of supported Sieve extensions;\n"
                                          "without it, KMail cannot install out-of-"
@@ -107,7 +107,7 @@ void Vacation::slotGetResult(KManageSieve::SieveJob *job, bool success,
         return;
     }
 
-    const bool supportsDate = job->sieveCapabilities().contains(QStringLiteral("date"));
+    const bool supportsDate = job->sieveCapabilities().contains(QLatin1String("date"));
 
     if (!mDialog && !mCheckOnly) {
         mDialog = new VacationDialog(i18n("Configure \"Out of Office\" Replies"), nullptr);
@@ -120,7 +120,7 @@ void Vacation::slotGetResult(KManageSieve::SieveJob *job, bool success,
 
     KSieveUi::VacationUtils::Vacation vacation = KSieveUi::VacationUtils::parseScript(script);
 
-    if (!mCheckOnly && (!success || (!vacation.isValid()  && !script.trimmed().isEmpty()))) {
+    if (!mCheckOnly && (!success || (!vacation.isValid() && !script.trimmed().isEmpty()))) {
         KMessageBox::information(nullptr, i18n("Someone (probably you) changed the "
                                                "vacation script on the server.\n"
                                                "KMail is no longer able to determine "
@@ -155,10 +155,10 @@ void Vacation::slotGetResult(KManageSieve::SieveJob *job, bool success,
     Q_EMIT scriptActive(mWasActive, mServerName);
     if (mCheckOnly && mWasActive) {
         if (KMessageBox::questionYesNo(nullptr, i18n("There is still an active out-of-office reply configured.\n"
-                                       "Do you want to edit it?"), i18n("Out-of-office reply still active"),
+                                                     "Do you want to edit it?"), i18n("Out-of-office reply still active"),
                                        KGuiItem(i18n("Edit"), QStringLiteral("document-properties")),
                                        KGuiItem(i18n("Ignore"), QStringLiteral("dialog-cancel")))
-                == KMessageBox::Yes) {
+            == KMessageBox::Yes) {
             Q_EMIT requestEditVacation();
         }
     }
@@ -185,7 +185,7 @@ void Vacation::slotDialogOk()
     vacation.endDate = mDialog->endDate();
     vacation.endTime = mDialog->endTime();
     const QString script = VacationUtils::composeScript(vacation);
-    emit scriptActive(active, mServerName);
+    Q_EMIT scriptActive(active, mServerName);
 
     qCDebug(LIBKSIEVE_LOG) << "script:" << endl << script;
 
@@ -225,12 +225,13 @@ void Vacation::slotPutInactiveResult(KManageSieve::SieveJob *job, bool success)
 
 void Vacation::handlePutResult(KManageSieve::SieveJob *, bool success, bool activated)
 {
-    if (success)
+    if (success) {
         KMessageBox::information(nullptr, activated
                                  ? i18n("Sieve script installed successfully on the server.\n"
                                         "Out of Office reply is now active.")
                                  : i18n("Sieve script installed successfully on the server.\n"
                                         "Out of Office reply has been deactivated."));
+    }
 
     qCDebug(LIBKSIEVE_LOG) << "( ???," << success << ", ? )";
     mSieveJob = nullptr; // job deletes itself after returning from this slot!
@@ -246,4 +247,3 @@ void Vacation::showVacationDialog()
         mDialog->activateWindow();
     }
 }
-
