@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -170,7 +170,7 @@ void ManageSieveWidget::slotContextMenuRequested(const QPoint &p)
     } else if (!item->parent()) {
         // top-levels:
         const bool jobsListIsEmpty = mJobs.keys(item).isEmpty();
-        if (!serverHasError(item) && jobsListIsEmpty) {
+        if (canAddNewScript(item, jobsListIsEmpty)) {
             menu.addAction(QIcon::fromTheme(QStringLiteral("document-new")), i18n("New Script..."), this, &ManageSieveWidget::slotNewScript);
         } else if (!jobsListIsEmpty) { //In Progress
             menu.addAction(KStandardGuiItem::cancel().icon(), KStandardGuiItem::cancel().text(), this, &ManageSieveWidget::slotCancelFetch);
@@ -181,14 +181,34 @@ void ManageSieveWidget::slotContextMenuRequested(const QPoint &p)
     }
 }
 
+bool ManageSieveWidget::canAddNewScript(QTreeWidgetItem *item, bool jobsListIsEmpty)
+{
+    if (!serverHasError(item) && jobsListIsEmpty) {
+        if (item->parent()) {
+            item = item->parent();
+        }
+        if (!item) {
+            return false;
+        }
+
+        if (!mUrls.count(item)) {
+            return false;
+        }
+        return true;
+    }
+    return false;
+}
+
 void ManageSieveWidget::slotCancelFetch()
 {
     QTreeWidgetItem *item = d->mTreeView->currentItem();
     if (item) {
         const QList<KManageSieve::SieveJob *> jobs = mJobs.keys(item);
         for (KManageSieve::SieveJob *job : jobs) {
-            job->kill();
+            job->kill(KJob::EmitResult);
         }
+    } else {
+        qCWarning(LIBKSIEVE_LOG) << "ManageSieveWidget::slotCancelFetch(): item is not selected";
     }
 }
 
